@@ -154,16 +154,19 @@ class Severity(str, Enum):
     INFO = "INFO"
 
 
-class CWE(ID):
+class CWE(BaseModel):
+    id: str
+    summary: str = ""
     pass
 
 
-class CVE(ID):
-    identifier: str
+class CVE(BaseModel):
+    id: str
     year: int = 2000
     summary: str = ""
-    # cvss: CVSS3 = None
-    cwe: CWE = None
+    score: Optional[float]
+    cvss: str = ""
+    
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
@@ -184,13 +187,11 @@ class BaseFinding(BaseSchema):
     score: Optional[float]
     description: str = ""
     cve: list[CVE] = []
-
-    # class Config:
-    #     arbitrary_types_allowed = True
+    cwe: list[CWE] = []
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
-        if not self.score == None:
+        if self.score:
             if self.score == 0.0:
                 self.severity = Severity.INFO
             elif self.score < 4.0:
@@ -210,8 +211,7 @@ class BaseFinding(BaseSchema):
 
 class Finding(BaseFinding, ID):
     pass
-    # class Config:
-    #     arbitrary_types_allowed = True
+
     
 
 class RawResultHeader(BaseSchema):
@@ -234,29 +234,30 @@ class ModuleSpec(BaseSchema):
     env: list[dict[str, str]]
     
 
-class CampaignModule(BaseSchema):
-    """A user-specified module scoped to a single campaign"""
-    name: str 
-    campaign_id: UUID4
-
 
 class KafkaHeader(BaseModel):
     module: str
-    campaign_id: UUID4 = b""
-    service_ids: list[UUID4] = []
-    asset_id: list[UUID4] = []
+    campaign: Optional[Campaign]
+    services: Optional[list[Service]]
+    assets: Optional[list[Asset]]
 
     def form(self) -> list[tuple[(str, bytes)]]:
         """Create headers suitable for Kafka messages"""
         items = json.loads(self.json()).items()
         headers = []
         for k, v in items:
-            if isinstance(v, UUID4):
-                headers.append((k, str(v).encode('latin-1')))
-            elif isinstance(v, list):
+            if isinstance(v, list):
                 headers.append((k, json.dumps(v).encode('latin-1')))
             else:
                 assert type(v) == str
                 headers.append((k, v.encode('latin-1')))
         
-        return headers
\ No newline at end of file
+        return headers
+    
+    def to_envars(self) -> list[tuple[(str, str)]]:
+        return [
+            {"name": "ULTIMA_CAMPAIGN", "value": json.dumps(self.campaign)},
+            {"name": "ULTIMA_SERVICES", "value": json.dumps(self.services)},
+            {"name": "ULTIMA_ASSETS", "value": json.dumps(self.services)},
+            {"name": "ULTIMA_MODULE", "value": self.module}
+        ]
\ No newline at end of file
